### Iniziare

PDFMathTranslate è un potente strumento di traduzione PDF. Puoi installare e iniziare a utilizzare questo strumento in vari modi.

---

### Installazione

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Consigliato per Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Consigliato per Linux</small>
3. [**uv** (un gestore di pacchetti Python)](./INSTALLATION_uv.md) <small>Consigliato per macOS</small>

---

### Utilizzo

1. [Utilizzo dell'**interfaccia Web**](./USAGE_webui.md)
2. [Utilizzo del **plugin Zotero**](https://github.com/guaguastandup/zotero-pdf2zh) (Programma di terze parti)
3. [Utilizzo della **riga di comando**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>